==> firebase_repository-1.0.8.tar.gz: lib/src/entities/automatismo_programado_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:equatable/equatable.dart';

class AutomatismoProgramadoEntity extends Equatable {
  final String uuid;
  final String dieta;
  final DateTime fecha;
  final double incremento;
  final double decremento;


  AutomatismoProgramadoEntity(this.uuid, this.dieta, this.fecha,
      this.incremento, this.decremento);

  Map<String, Object> toJson() {
    return {
      'uuid': this.uuid,
      'dieta': this.dieta,
      'fecha': this.fecha,
      'incremento': this.incremento,
      'decremento': this.decremento
    };
  }


  @override
  String toString() {
    return 'AutomatismoProgramadoEntity{uuid: $uuid, dieta: $dieta, fecha: $fecha, incremento: $incremento, decremento: $decremento}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          super == other &&
              other is AutomatismoProgramadoEntity &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              dieta == other.dieta &&
              fecha == other.fecha &&
              incremento == other.incremento &&
              decremento == other.decremento;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      dieta.hashCode ^
      fecha.hashCode ^
      incremento.hashCode ^
      decremento.hashCode;

  static AutomatismoProgramadoEntity fromJson(Map<String, Object> json) {
    return AutomatismoProgramadoEntity(
        json['uuid'] as String,
        json['dieta'] as String,
        json['fecha'] as DateTime,
        json['incremento'] as double,
        json['decremento'] as double
    );
  }

  static AutomatismoProgramadoEntity fromSnapshot(DocumentSnapshot snap) {
    return AutomatismoProgramadoEntity(snap.documentID, snap.data['dieta'],
        snap.data['fecha'].toDate(), snap.data['incremento'], snap.data['decremento']);
  }

  Map<String, Object> toDocument() {
    return {'dieta': this.dieta, 'fecha': this.fecha, 'incremento': this.incremento, 'decremento': this.decremento};
  }
}

==> firebase_repository-1.0.48.tar.gz: lib/src/entities/automatismo_programado_entity.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';
import 'package:equatable/equatable.dart';

class AutomatismoProgramadoEntity extends Equatable {
  final String uuid;
  final String dieta;
  final DateTime fecha;
  final double incremento;
  final double decremento;

  AutomatismoProgramadoEntity(
      this.uuid, this.dieta, this.fecha, this.incremento, this.decremento);

  Map<String, Object> toJson() {
    return {
      'uuid': this.uuid,
      'dieta': this.dieta,
      'fecha': this.fecha,
      'incremento': this.incremento,
      'decremento': this.decremento
    };
  }

  @override
  String toString() {
    return 'AutomatismoProgramadoEntity{uuid: $uuid, dieta: $dieta, fecha: $fecha, incremento: $incremento, decremento: $decremento}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is AutomatismoProgramadoEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          dieta == other.dieta &&
          fecha == other.fecha &&
          incremento == other.incremento &&
          decremento == other.decremento;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      dieta.hashCode ^
      fecha.hashCode ^
      incremento.hashCode ^
      decremento.hashCode;

  static AutomatismoProgramadoEntity fromJson(Map<String, Object> json) {
    return AutomatismoProgramadoEntity(
        json['uuid'] as String,
        json['dieta'] as String,
        json['fecha'] as DateTime,
        json['incremento'] as double,
        json['decremento'] as double);
  }

  static AutomatismoProgramadoEntity fromSnapshot(DocumentSnapshot snap) {
    return AutomatismoProgramadoEntity(
        snap.documentID,
        snap.data['dieta'],
        snap.data['fecha'].toDate(),
        double.parse(snap.data['incremento'].toString()),
        double.parse(snap.data['decremento'].toString()));
  }

  Map<String, Object> toDocument() {
    return {
      'dieta': this.dieta,
      'fecha': this.fecha,
      'incremento': this.incremento,
      'decremento': this.decremento
    };
  }
}
